"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyvAdapter = void 0;
const keyv_1 = __importDefault(require("keyv"));
const dataloader_1 = __importDefault(require("dataloader"));
class KeyvAdapter {
    constructor(keyv, options) {
        this.keyv = keyv !== null && keyv !== void 0 ? keyv : new keyv_1.default();
        this.dataLoader = (options === null || options === void 0 ? void 0 : options.disableBatchReads)
            ? undefined
            : new dataloader_1.default((keys) => this.keyv.get([...keys]), { cache: false });
    }
    async get(key) {
        return this.dataLoader ? this.dataLoader.load(key) : this.keyv.get(key);
    }
    async set(key, value, opts) {
        if (typeof (opts === null || opts === void 0 ? void 0 : opts.ttl) === "number" && !Number.isNaN(opts.ttl)) {
            await this.keyv.set(key, value, opts.ttl * 1000);
        }
        else {
            await this.keyv.set(key, value);
        }
    }
    async delete(key) {
        return this.keyv.delete(key);
    }
}
exports.KeyvAdapter = KeyvAdapter;
//# sourceMappingURL=index.js.map